EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'AssessmentTypes_CreateOrUpdateAssessmentType',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new vulnerability assessment type or updates an existing one.'
GO

IF OBJECT_ID('[AssessmentTypes_CreateOrUpdateAssessmentType]') IS NOT NULL DROP PROCEDURE [AssessmentTypes_CreateOrUpdateAssessmentType]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [AssessmentTypes_CreateOrUpdateAssessmentType]
(
	@AssessmentType_Name NVARCHAR(200),
	@BlockDownload_Indicator YNINDICATOR,
	@Expiration_Days INT,
	@Severity_Code CHAR(1),
	@Custom_Color INT,
	@AssessmentType_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @AssessmentType_Id IS NULL
	BEGIN

		INSERT INTO [AssessmentTypes]
		(
			[AssessmentType_Name],
			[BlockDownload_Indicator],
			[Expiration_Days],
			[Severity_Code],
			[Custom_Color]
		)
		VALUES
		(
			@AssessmentType_Name,
			@BlockDownload_Indicator,
			@Expiration_Days,
			@Severity_Code,
			@Custom_Color
		)

		SET @AssessmentType_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [AssessmentTypes]
		   SET [AssessmentType_Name] = @AssessmentType_Name,
		       [BlockDownload_Indicator] = @BlockDownload_Indicator,
			   [Expiration_Days] = @Expiration_Days,
			   [Severity_Code] = @Severity_Code,
			   [Custom_Color] = @Custom_Color
		 WHERE [AssessmentType_Id] = @AssessmentType_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [AssessmentTypes_CreateOrUpdateAssessmentType] TO [ProGetUser_Role]
GO