EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'MavenArtifacts_CreateOrUpdateArtifact',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new Maven artifact or updates an existing one.'
GO

IF OBJECT_ID('[MavenArtifacts_CreateOrUpdateArtifact]') IS NOT NULL DROP PROCEDURE [MavenArtifacts_CreateOrUpdateArtifact]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [MavenArtifacts_CreateOrUpdateArtifact]
(
	@Feed_Id INT,
	@GroupId_Text NVARCHAR(200),
	@ArtifactId_Text NVARCHAR(100),
	@Version_Text NVARCHAR(50),
	@File_Type NVARCHAR(50),
	@FileName_Text NVARCHAR(100),
	@File_SHA1_Bytes BINARY(20),
	@File_MD5_Bytes BINARY(16),
	@File_Size BIGINT,
	@Updated_Date DATETIME,
	@Cached_Indicator YNINDICATOR,
	@Name_Text NVARCHAR(50),
	@Description_Text VARBINARY(MAX),
	@LatestVersion_Text NVARCHAR(50)
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @MavenArtifact_Id INT
	SET @MavenArtifact_Id = (SELECT [MavenArtifact_Id]
	                           FROM [MavenArtifacts]
	                           WITH (UPDLOCK)
	                          WHERE [Feed_Id] = @Feed_Id AND [GroupId_Text] = @GroupId_Text AND [ArtifactId_Text] = @ArtifactId_Text)

	IF @MavenArtifact_Id IS NULL
	BEGIN

		INSERT INTO [MavenArtifacts]
		(
			[Feed_Id],
			[GroupId_Text],
			[ArtifactId_Text],
			[Name_Text],
			[Description_Text],
			[LatestVersion_Text]
		)
		VALUES
		(
			@Feed_Id,
			@GroupId_Text,
			@ArtifactId_Text,
			@Name_Text,
			@Description_Text,
			@LatestVersion_Text
		)

		SET @MavenArtifact_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [MavenArtifacts]
		   SET [Name_Text] = COALESCE(@Name_Text, [Name_Text]),
		       [Description_Text] = COALESCE(@Description_Text, [Description_Text]),
		       [LatestVersion_Text] = @LatestVersion_Text
		 WHERE [MavenArtifact_Id] = @MavenArtifact_Id

	END

	IF EXISTS(SELECT * FROM [MavenArtifactFiles] WITH (UPDLOCK) WHERE [MavenArtifact_Id] = @MavenArtifact_Id AND [Version_Text] = @Version_Text AND [File_Type] = @File_Type AND COALESCE([FileName_Text], @ArtifactId_Text + '-' + @Version_Text) = COALESCE(@FileName_Text, @ArtifactId_Text + '-' + @Version_Text))
	BEGIN

		UPDATE [MavenArtifactFiles]
		   SET [File_SHA1_Bytes] = @File_SHA1_Bytes,
		       [File_MD5_Bytes] = @File_MD5_Bytes,
			   [File_Size] = @File_Size,
			   [Updated_Date] = @Updated_Date,
			   [Cached_Indicator] = @Cached_Indicator
		 WHERE [MavenArtifact_Id] = @MavenArtifact_Id
		   AND [Version_Text] = @Version_Text
		   AND [File_Type] = @File_Type
		   AND COALESCE([FileName_Text], @ArtifactId_Text + '-' + @Version_Text) = COALESCE(@FileName_Text, @ArtifactId_Text + '-' + @Version_Text)

		EXEC [Events_RaiseEvent] 'PKGMDF', @Feed_Id, 'Package_Name', @ArtifactId_Text, 'Package_Version', @Version_Text

	END
	ELSE
	BEGIN

		INSERT INTO [MavenArtifactFiles]
		(
			[MavenArtifact_Id],
			[Version_Text],
			[File_Type],
			[FileName_Text],
			[File_SHA1_Bytes],
			[File_MD5_Bytes],
			[File_Size],
			[Updated_Date],
			[Cached_Indicator],
			[Download_Count]
		)
		VALUES
		(
			@MavenArtifact_Id,
			@Version_Text,
			@File_Type,
			COALESCE(@FileName_Text, @ArtifactId_Text + '-' + @Version_Text),
			@File_SHA1_Bytes,
			@File_MD5_Bytes,
			@File_Size,
			@Updated_Date,
			@Cached_Indicator,
			0
		)

		EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Package_Name', @ArtifactId_Text, 'Package_Version', @Version_Text

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [MavenArtifacts_CreateOrUpdateArtifact] TO [ProGetUser_Role]